@@ -1,4 +1,4 @@
-/* Copyright (C) 1994, 1995, 1996, 1997, 1998, 2000, 2001, 2002 Free Software Foundation, Inc.
+/* Copyright (C) 1994, 1995, 1996, 1997, 1998, 2000, 2001, 2002, 2004 Free Software Foundation, Inc.
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
@@ -366,10 +366,12 @@ char *scm_usage_name = 0;
 void
 scm_shell_usage (int fatal, char *message)
 {
-  if (message)
-    fprintf (stderr, "%s\n", message);
+  FILE  *fp = (fatal ? stderr : stdout);
 
-  fprintf (stderr, 
+  if (message)
+    fprintf (fp, "%s\n", message);
+
+  fprintf (fp, 
            "Usage: %s OPTION ...\n"
            "Evaluate Scheme code, interactively or from a script.\n"
            "\n"
@@ -390,7 +392,9 @@ scm_shell_usage (int fatal, char *message)
 	   "                 which is a list of numbers like \"2,13,14\"\n"
            "  -h, --help     display this help and exit\n"
            "  -v, --version  display version information and exit\n"
-	   "  \\              read arguments from following script lines\n",
+	   "  \\              read arguments from following script lines\n"
+           "\n"
+	   "Report bugs to bug-guile@gnu.org\n",
            scm_usage_name);
 
   if (fatal)
@@ -584,7 +588,7 @@ scm_compile_shell_switches (int argc, char **argv)
 	{
 	  /* Print version number.  */
 	  printf ("Guile %s\n"
-		  "Copyright (c) 1995, 1996, 1997, 2000, 2001, 2002, 2003 Free Software Foundation\n"
+		  "Copyright (c) 1995, 1996, 1997, 2000, 2001, 2002, 2003, 2004 Free Software Foundation\n"
 		  "Guile may be distributed under the terms of the GNU General Public Licence;\n"
 		  "certain other uses are permitted as well.  For details, see the file\n"
 		  "`COPYING', which is included in the Guile distribution.\n"
